@@ -49,7 +49,6 @@
 #' \url{http://www.bom.gov.au/climate/cdo/about/site-num.shtml}
 #'
 #' @author Adam H Sparks, \email{adamhsparks@gmail.com}
-#' @importFrom rlang .data
 #' @export
 get_ag_bulletin <- function(state = "AUS") {
   # CRAN NOTE avoidance
@@ -121,6 +120,7 @@ get_ag_bulletin <- function(state = "AUS") {
 
   obs <- xml2::xml_find_all(xmlbulletin, "//obs")
 
+  # create the tidy dataframe --------------------------------------------------
   tidy_df <- lapply(X = obs, FUN = .get_obs)
   tidy_df <- do.call("rbind", tidy_df)
   tidy_df$product_id <- substr(basename(xmlbulletin_url),
@@ -131,51 +131,44 @@ get_ag_bulletin <- function(state = "AUS") {
                               stations_site_list,
                               by = c("site" = "site"))
 
-  tidy_df <-
-    tidy_df %>%
-    dplyr::mutate_at(tidy_df,
-                     .funs = as.character,
-                     .vars = "time.zone") %>%
-    dplyr::rename(
-      obs_time_local = .data$obs.time.local,
-      obs_time_utc = .data$obs.time.utc,
-      time_zone = .data$time.zone,
-      full_name = .data$name
-    )
+  tidy_df["time.zone"] <- as.character(tidy_df["time.zone"])
 
-  tidy_df <-
-    tidy_df %>%
-    dplyr::select(
-      .data$product_id,
-      .data$state,
-      .data$dist,
-      .data$wmo,
-      .data$site,
-      .data$station,
-      .data$full_name,
-      .data$obs_time_local,
-      .data$obs_time_utc,
-      .data$time_zone,
-      .data$lat,
-      .data$lon,
-      .data$elev,
-      .data$bar_ht,
-      .data$start,
-      .data$end,
-      .data$r,
-      .data$tn,
-      .data$tx,
-      .data$twd,
-      .data$ev,
-      .data$tg,
-      .data$sn,
-      .data$t5,
-      .data$t10,
-      .data$t20,
-      .data$t50,
-      .data$t1m,
-      .data$wr
-    )
+  names(tidy_df)[c(1:3, 21)] <-
+    c("obs_time_local", "obs_time_utc", "time_zone", "full_name")
+
+  refcols <- c(
+      "product_id",
+      "state",
+      "dist",
+      "wmo",
+      "site",
+      "station",
+      "full_name",
+      "obs_time_local",
+      "obs_time_utc",
+      "time_zone",
+      "lat",
+      "lon",
+      "elev",
+      "bar_ht",
+      "start",
+      "end",
+      "r",
+      "tn",
+      "tx",
+      "twd",
+      "ev",
+      "tg",
+      "sn",
+      "t5",
+      "t10",
+      "t20",
+      "t50",
+      "t1m",
+      "wr"
+      )
+
+  tidy_df <- tidy_df[c(refcols, setdiff(names(tidy_df), refcols))]
 
   # convert dates to POSIXct -------------------------------------------------
   tidy_df[, c("obs_time_local", "obs_time_utc")] <-
@@ -210,7 +203,7 @@ get_ag_bulletin <- function(state = "AUS") {
   # if there are no observations, keep a single row for the station ID
   if (length(value) > 1) {
     location <-
-      trimws(location[rep(seq_len(nrow(location)), each = length(value)),])
+      trimws(location[rep(seq_len(nrow(location)), each = length(value)), ])
   }
 
   # if there is only one observation this step means that a data frame is
